@@ -318,6 +318,15 @@ add_exe_suffix_on_Windows <- function(files, OS=get_OS_arch()[["OS"]])
     paste0(files, ".exe")
 }
 
+named_list_as_character <- function(x, sep="; ")
+{
+    stopifnot(is.list(x))
+    x_names <- names(x)
+    stopifnot(!is.null(x_names))
+    x <- lapply(x, function(x) paste(x, collapse=sep))
+    paste0(x_names, ": ", as.character(x))
+}
+
 display_local_file_in_browser <- function(file)
 {
     top_html <- tempfile()
